shithub: pokered

Download patch

ref: 4cccc2fdf80af4962f233f20c3ddd9a8f3fd13ca
parent: ec8413e3172efc4f306bf0e6d51e0056e6d6d97d
author: IIMarckus <iimarckus@gmail.com>
date: Mon Aug 16 17:11:43 EDT 2010

It’s official: if something needs doing, mark it with XXX.
If you’re not absolutely, positively sure a comment is
correct, mark it with XXX. Don’t leave anything that’s
not 100% clear unmarked, or nobody will ever fix it.

hg-commit-id: 8d23e2ad71eb


--- a/pokered.asm
+++ b/pokered.asm
@@ -2420,8 +2420,8 @@
 	ret nz
 
 ; set [W_ENEMYMONCOUNT] to 0, [$D89D] to FF
 ; first is total enemy pokemon?
 ; second is species of first pokemon?
 	ld hl,W_ENEMYMONCOUNT
 	xor a
 	ld [hli],a
@@ -2468,7 +2468,7 @@
 	ld a,[hli]
 	and a ; have we reached the end of the trainer data?
 	jr z,.FinishUp\@
-	ld [$CF91],a ; write species somewhere (why?)
+	ld [$CF91],a ; write species somewhere (XXX why?)
 	ld a,1
 	ld [$CC49],a
 	push hl
@@ -2555,7 +2555,7 @@
 .GiveStarterMove\@
 	ld a,b
 	ld [W_ENEMYMON6MOVE3],a
-.FinishUp\@ ; this needs documenting
+.FinishUp\@ ; XXX this needs documenting
 	xor a       ; clear D079-D07B
 	ld de,$D079
 	ld [de],a
@@ -2420,8 +2420,8 @@
 
 ; set [W_ENEMYMONCOUNT] to 0, [$D89D] to FF
-; first is total enemy pokemon?
-; second is species of first pokemon?
+; XXX first is total enemy pokemon?
+; XXX second is species of first pokemon?
 	ld hl,W_ENEMYMONCOUNT
 	xor a